# -*- coding: utf-8 -*-

# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

TRAITS = [
    # ref: https://specs.openstack.org/openstack/nova-specs/specs/stein/
    # approved/add-emulated-virtual-tpm.html
    # support for TPM 1.2
    'TPM_1_2',
    # support for TPM 2.0
    'TPM_2_0',
    # support for UEFI Secure Boot
    # ref:
    # https://opendev.org/openstack/nova-specs/src/branch/master/specs/wallaby/approved/allow-secure-boot-for-qemu-kvm-guests.rst#fnref8
    'UEFI_SECURE_BOOT'
]
